Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DeleteUnused ¶
func DeleteUnused()
DeleteUnused deletes any cache entries that have not been accessed since the cache was loaded. Use this in generate functions that save all generated cache.
func Get ¶
Get tries to get a cached path for given equation at given fontsize in dots. returns nil if not available.
func Open ¶
Open opens saved cache entries from given file If the filename ends in .gz, it is unzipped for reading.
func OpenFS ¶
OpenFS opens saved cache entries from given file system (e.g., for embed). If the filename ends in .gz, it is unzipped for reading.
func SaveAs ¶
SaveAs saves cache entries to given file If the filename ends in .gz, it is zipped. When generating, can call DeleteUnused to filter all unused items.
func SetShapeMath ¶
func SetShapeMath()
SetShapeMath sets the standard text shaping math function to use only cached math paths, not live generation of paths from TeX. This saves a lot of memory in the resulting executable, and is recommended for any math-heavy uses where all the equations can be cached in advance (e.g., the content system).
Types ¶
This section is empty.